README
===============
официальный релиз:
https://github.com/python-excel/xlrd/releases/tag/0.9.4

Данный пакет является форком xlrd версии 0.9.4
Отличие:
    - убраны вызовы time.clock(), т.к. более не поддерживаются в python>=3.8